==> tine20-allinone_2020.08.8.tar.bz2: Tasks/js/Tasks-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fr\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Tâche"
 ,"Tâches"

]
, "Percent"
: "Pourcent"

, "Completed"
: "Terminé"

, "Due"
: "Date de fin"

, "Class"
: ""

, "Description"
: "Description"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organisateur"

, "Priority"
: "Priorité"

, "Status, Status"
: [
  "Statut"
 ,"Statuts"

]
, "Lead"
: "Prospect"

, "Telephone"
: "Téléphone"

, "Email"
: "Adresse électronique"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Vous devez indiquer une date de fin, car l'alerte est activée !"

, "Summary"
: "Résumé"

, "Due date"
: "Date de fin"

, "Add Responsible ..."
: "Ajouter un responsable..."

, "Notes"
: "Notes"

, "Enter description..."
: "Saisissez une description..."

, "Percentage"
: "Pourcentage"

, "Tasks"
: "Tâches"

, "to do list, to do lists"
: [
  "liste de tâches"
 ,"listes de tâches"

]
, "to do lists"
: "listes de tâches"

, "Quick Search"
: "Recherche rapide"

, "Due Date"
: "Date de fin"

, "Responsible"
: "Responsable"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Modifié par"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créé par"

, "New Task"
: "Nouvelle tâche"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Êtes-vous sûr de vouloir supprimer la tâche sélectionnée?"
 ,"Êtes-vous sûr de vouloir supprimer les tâches sélectionnées?"

]
, "Attachments"
: ""

, "Tags"
: "Marqueur"

, "Lead name"
: ""

, "Add a task..."
: "Ajouter"

, "All my tasks"
: "Toutes mes tâches"

, "Default Favorite"
: "Favoris par défaut"

, "The default favorite which is loaded on Tasks startup"
: "Favori qui sera chargé au démarrage des Tâches"

, "Default Task List"
: "Liste de tâches par défaut"

, "The default task list to create new tasks in."
: "Liste où seront créées par défaut les nouvelles tâches"

, "Tasks status available"
: "Statut pour une tâche"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Statuts disponibles pour une tâche. Attention, certaines valeurs peuvent impacter d'autres modules."

, "No response"
: "Pas de réponse"

, "Cancelled"
: "Annulée"

, "In process"
: "En cours"

, "Task priorities available"
: "Priorité pour tâche"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Priorités disponibles pour une tâche. Attention, certaines valeurs peuvent impacter d'autres modules."

, "low"
: "basse"

, "normal"
: "normal"

, "high"
: "haute"

, "urgent"
: "urgent"

, "manage shared task lists"
: "gérer les listes de tâches partagées"

, "Create new shared tasks lists"
: "Ajouter une liste de tâches partagées"

, "manage shared tasks favorites"
: "gérer les favoris des tâches partagées"

, "Create or update shared tasks favorites"
: "Créer ou mettre a jour les favoris des tâches partagées"

, "%s's personal tasks"
: "Tâches personnelles de %s"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Toutes les tâches de ma liste"

, "My open tasks"
: "Mes tâches en cours"

, "My open tasks this week"
: "Mes tâches en cours pour cette semaine"

, "All tasks for me"
: "Toutes mes tâches"

, "All tasks that I am responsible for"
: "Toutes les tâches dont je suis responsable"

, "Last modified by me"
: "Mes dernières modifications"

, "All tasks that I have last modified"
: "Toutes les tâches que j'ai modifié dernièrement"

, "Tasks without responsible"
: "Tâches sans responsable"

, "GENDER_Task"
: ""

, "Task"
: "Tâche"

, "Status"
: "Statut"

, "to do list"
: "liste de tâches"

, "Do you really want to delete the selected task?"
: "Êtes-vous sûr de vouloir supprimer la tâche sélectionnée?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-fr-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Vous devez indiquer une date de fin, car l'alerte est activée !"

, "Summary"
: "Résumé"

, "Due date"
: "Date de fin"

, "Priority"
: "Priorité"

, "Organizer"
: "Organisateur"

, "Add Responsible ..."
: "Ajouter un responsable..."

, "Notes"
: "Notes"

, "Enter description..."
: "Saisissez une description..."

, "Percentage"
: "Pourcentage"

, "Status, Status"
: [
  "Statut"
 ,"Statuts"

]
, "Completed"
: "Terminé"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Êtes-vous sûr de vouloir supprimer la tâche sélectionnée?"
 ,"Êtes-vous sûr de vouloir supprimer les tâches sélectionnées?"

]
, "Attachments"
: ""

, "Tags"
: "Marqueur"

, "Lead name"
: ""

, "Add a task..."
: "Ajouter"

, "Due Date"
: "Date de fin"

, "Percent"
: "Pourcent"

, "Responsible"
: "Responsable"

, "Task, Tasks"
: [
  "Tâche"
 ,"Tâches"

]
, "Tasks"
: "Tâches"

, "to do list, to do lists"
: [
  "liste de tâches"
 ,"listes de tâches"

]
, "to do lists"
: "listes de tâches"

, "Quick Search"
: "Recherche rapide"

, "Last Modified Time"
: "Dernière modification"

, "Last Modified By"
: "Modifié par"

, "Creation Time"
: "Date de création"

, "Created By"
: "Créé par"

, "New Task"
: "Nouvelle tâche"

, "All my tasks"
: "Toutes mes tâches"

, "Default Favorite"
: "Favoris par défaut"

, "The default favorite which is loaded on Tasks startup"
: "Favori qui sera chargé au démarrage des Tâches"

, "Default Task List"
: "Liste de tâches par défaut"

, "The default task list to create new tasks in."
: "Liste où seront créées par défaut les nouvelles tâches"

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Statut pour une tâche"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Statuts disponibles pour une tâche. Attention, certaines valeurs peuvent impacter d'autres modules."

, "No response"
: "Pas de réponse"

, "Cancelled"
: "Annulée"

, "In process"
: "En cours"

, "Task priorities available"
: "Priorité pour tâche"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Priorités disponibles pour une tâche. Attention, certaines valeurs peuvent impacter d'autres modules."

, "low"
: "basse"

, "normal"
: "normal"

, "high"
: "haute"

, "urgent"
: "urgent"

, "%s's personal tasks"
: "Tâches personnelles de %s"

, "GENDER_Task"
: ""

, "Due"
: "Date de fin"

, "Class"
: ""

, "Description"
: "Description"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Prospect"

, "Telephone"
: "Téléphone"

, "Email"
: "Adresse électronique"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Toutes les tâches de ma liste"

, "My open tasks"
: "Mes tâches en cours"

, "My open tasks this week"
: "Mes tâches en cours pour cette semaine"

, "All tasks for me"
: "Toutes mes tâches"

, "All tasks that I am responsible for"
: "Toutes les tâches dont je suis responsable"

, "Last modified by me"
: "Mes dernières modifications"

, "All tasks that I have last modified"
: "Toutes les tâches que j'ai modifié dernièrement"

, "Tasks without responsible"
: "Tâches sans responsable"

, "manage shared task lists"
: "gérer les listes de tâches partagées"

, "Create new shared tasks lists"
: "Ajouter une liste de tâches partagées"

, "manage shared tasks favorites"
: "gérer les favoris des tâches partagées"

, "Create or update shared tasks favorites"
: "Créer ou mettre a jour les favoris des tâches partagées"

, "Status"
: "Statut"

, "Do you really want to delete the selected task?"
: "Êtes-vous sûr de vouloir supprimer la tâche sélectionnée?"

, "Task"
: "Tâche"

, "to do list"
: "liste de tâches"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
